@@ -173,18 +173,19 @@ class PreScan(VisitorBase):
             "can't have both aggregation and window",
         )
 
-        # get join details
-        joined: Set[str] = set([self.joins[0].df_name])
-        for i in range(1, len(self.joins)):
-            j = self.joins[i]
-            right = j.df_name
-            v = self.copy(JoinCriteria)
-            v._joined, v._right_name = joined, right
-            if j.criteria_context is not None:
-                j.set_conditions(v.visit(j.criteria_context))
-            else:
-                j.set_conditions([])
-            joined.add(right)
+        if len(self.joins) > 0:
+            # get join details
+            joined: Set[str] = set([self.joins[0].df_name])
+            for i in range(1, len(self.joins)):
+                j = self.joins[i]
+                right = j.df_name
+                v = self.copy(JoinCriteria)
+                v._joined, v._right_name = joined, right
+                if j.criteria_context is not None:
+                    j.set_conditions(v.visit(j.criteria_context))
+                else:
+                    j.set_conditions([])
+                joined.add(right)
 
         # handle agg
         self.set("non_agg_mentions", self._non_agg_mentions)
@@ -690,6 +691,10 @@ class FromVisitor(ExpressionVisitor):
     def visitRegularQuerySpecification(
         self, ctx: qp.RegularQuerySpecificationContext
     ) -> None:
+        if len(self.joins) == 0:
+            self.update_current(None)  # type: ignore
+            self.set("encoded_map", self._encoded_map)
+            return
         joined = self._extract_df(self.joins[0].df_name)
         for join in self.joins[1:]:
             name = join.df_name
