@@ -43,6 +43,10 @@ class QPDDaskEngine(QPDEngine):
         return Column(value, name)
 
     def to_native(self, df: DataFrame) -> Any:
+        if all(not self.is_series(x.native) for x in df.values()):
+            return pd.from_pandas(
+                pandas.DataFrame({k: [v.native] for k, v in df.items()}), npartitions=2
+            )
         values = {k: v.native for k, v in df.items() if not self.is_series(v.native)}
         series = [v.native.rename(k) for k, v in df.items() if self.is_series(v.native)]
         assert_or_throw(
