@@ -36,6 +36,8 @@ class QPDPandasEngine(QPDEngine):
         return Column(value, name)
 
     def to_native(self, df: DataFrame) -> Any:
+        if all(not self.is_series(x.native) for x in df.values()):
+            return pd.DataFrame({k: [v.native] for k, v in df.items()})
         return pd.DataFrame({k: v.native for k, v in df.items()})
 
     def is_series(self, obj: Any) -> bool:
