@@ -42,6 +42,8 @@ class QPDRayEngine(QPDEngine):
         return Column(value, name)
 
     def to_native(self, df: DataFrame) -> Any:
+        if all(not self.is_series(x.native) for x in df.values()):
+            return pd.DataFrame({k: [v.native] for k, v in df.items()})
         values = {k: v.native for k, v in df.items() if not self.is_series(v.native)}
         series = [v.native.rename(k) for k, v in df.items() if self.is_series(v.native)]
         assert_or_throw(
