@@ -1,11 +1,10 @@
 import pandas as pd
 from pytest import raises
-
 from qpd._parser.sql import QPDSql
 from qpd._parser.utils import VisitorContext
 from qpd._parser.visitors import PreScan, StatementVisitor
+from qpd.workflow import QPDWorkflow, QPDWorkflowContext, WorkflowDataFrame
 from qpd_pandas import QPDPandasEngine
-from qpd.workflow import QPDWorkflow, QPDWorkflowContext
 from qpd_test import assert_df_eq
 
 
@@ -233,13 +232,37 @@ def test_pre_scan_join():
 def test_op_precedence():
     a = pd.DataFrame([[1, 4], [2, 5]], columns=["a", "b"])
     assert_eq(
-        dict(a=a), "SELECT a+1 AS a, b FROM a", [[2, 4], [3, 5]], ["a", "b"],
+        dict(a=a),
+        "SELECT a+1 AS a, b FROM a",
+        [[2, 4], [3, 5]],
+        ["a", "b"],
     )
     assert_eq(
-        dict(a=a), "SELECT a+2*3 AS a, b FROM a", [[7, 4], [8, 5]], ["a", "b"],
+        dict(a=a),
+        "SELECT a+2*3 AS a, b FROM a",
+        [[7, 4], [8, 5]],
+        ["a", "b"],
     )
     assert_eq(
-        dict(a=a), "SELECT a+1-2*3/4 AS a, b FROM a", [[0.5, 4], [1.5, 5]], ["a", "b"],
+        dict(a=a),
+        "SELECT a+1-2*3/4 AS a, b FROM a",
+        [[0.5, 4], [1.5, 5]],
+        ["a", "b"],
+    )
+
+
+def test_const_select():
+    assert_eq(
+        {},
+        "SELECT 1 AS a, 1.5 AS b, TRUE AS c",
+        [[1, 1.5, True]],
+        ["a", "b", "c"],
+    )
+    assert_eq(
+        {},
+        "SELECT 1+2 AS a, 1.5*3 AS b, 'x' AS c",
+        [[3, 4.5, "x"]],
+        ["a", "b", "c"],
     )
 
 
@@ -1003,7 +1026,7 @@ def _debug_run(sql, rule, visitor, **kwargs):
     wf = QPDWorkflow(ctx)
     v = visitor(
         VisitorContext(
-            sql=sql, workflow=wf, current=wf.dfs[list(kwargs.keys())[0]], dfs=wf.dfs
+            sql=sql, workflow=wf, dfs=wf.dfs
         )
     )
     wf.assemble_output(v.visit(sql.tree))
